/***********************************************************
 * $Id: OdtTransform.java 13 2007-12-17 19:32:15Z lech $
 * 
 * OpenDocument transformation tool of the clazzes.org project
 * http://www.clazzes.org
 *
 * Copyright (C) 2006-2007 ev-i Informationstechnologie GmbH
 *
 * Created: 2006-12-18
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.odtransform;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.zip.ZipFile;

import javax.xml.transform.Source;
import javax.xml.transform.TransformerException;
import javax.xml.transform.sax.SAXResult;
import javax.xml.transform.sax.SAXTransformerFactory;
import javax.xml.transform.sax.TransformerHandler;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;

import org.xml.sax.SAXException;

/**
 * @author wglas
 *
 */
public class OdtTransform
{

    /**
     * @param args
     */
    public static void main(String[] args) throws Exception
    {
        String xsltFile = args[0];
        String odtFile = args[1];
        
        OutputStream out = System.out;
        
        if (args.length > 2)
            out = new FileOutputStream(args[2]);
    
        if (xsltFile.equals("--no-xslt"))
            transformPlain(odtFile, out);
        else
            transformOdt(xsltFile,odtFile,out);
    }
    
    public static void transformOdt(String xsltFile, String odtFile, OutputStream os) throws IOException, TransformerException, SAXException
    {
        SAXTransformerFactory transformerFactory =
            (SAXTransformerFactory) SAXTransformerFactory.newInstance();
        
        // set up xslt ftransformation.
        Source xsltSource = new StreamSource(new FileInputStream(xsltFile));
        
        TransformerHandler xsltHandler =
            transformerFactory.newTransformerHandler(xsltSource);
        
        xsltHandler.setResult(new StreamResult(os));
  
        OdtTransformer odtTransformer = new OdtTransformer();
        
        odtTransformer.transform(new ZipFile(odtFile),new SAXResult(xsltHandler));
    }
    
    public static void transformPlain(String odtFile, OutputStream os) throws IOException, TransformerException, SAXException
    {
        OdtTransformer odtTransformer = new OdtTransformer();
        
        odtTransformer.transform(new ZipFile(odtFile),new StreamResult(os));
    }

}
